# $Id: Windshield.pm 35957 2011-11-10 20:23:17Z wsl $
# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Windshield.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Windshield;

use Aselect::Handler -self;

sub handle {
	my $res = eval { super };
	return $res if $res;
	my $exc = $@;
	die $exc if UNIVERSAL::isa($exc, 'Xyzzy::Response');
	warn $exc;
	my $req = new Aselect::UI::Request(cfg => $self, ctx => shift);
	$res = $req->error('internal', $exc);
	$res->status(500);
	die $res;
}
